Change 27471 by [EMAIL PROTECTED] on 2006/03/11 10:21:27
Missed the hunk that adds regen_madly.pl to the regen_perl target.
Affected files ...
... //depot/perl/Makefile.SH#353 edit
Differences ...
==== //depot/perl/Makefile.SH#353 (text) ====
Index: perl/Makefile.SH
--- perl/Makefile.SH#352~27447~ 2006-03-09 12:48:18.000000000 -0800
+++ perl/Makefile.SH 2006-03-11 02:21:27.000000000 -0800
@@ -889,9 +889,10 @@
run_byacc:
@echo "run_byacc is obsolete; try 'make regen_perly' instead"
# this outputs perly.act and perly.tab
regen_perly:
perl regen_perly.pl
+ perl regen_madly.pl
# We don't want to regenerate perly.c and perly.h, but they might
# appear out-of-date after a patch is applied or a new distribution is
End of Patch.
@@ -889,9 +889,10 @@
run_byacc:
-# this outputs perly.act and perly.tab
+# this outputs perly.h, perly.act, perly.tab, madly.h, madly.act and madly.tab
regen_perly:
perl regen_perly.pl